@@ -14,19 +14,19 @@ using namespace GrantleeTheme;
 class GrantleeTheme::EnginePrivate
 {
 public:
-    EnginePrivate()
-    {
-    }
+    EnginePrivate() = default;
 
-    ~EnginePrivate()
-    {
-    }
+    ~EnginePrivate() = default;
 
     QWeakPointer<GrantleeKi18nLocalizer> localizer;
 };
 
 Engine::Engine(QObject *parent)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     : Grantlee::Engine(parent)
+#else
+    : KTextTemplate::Engine(parent)
+#endif
     , d(new GrantleeTheme::EnginePrivate)
 {
     addPluginPath(QStringLiteral(GRANTLEE_PLUGIN_INSTALL_DIR));
@@ -36,10 +36,7 @@ Engine::Engine(QObject *parent)
     setSmartTrimEnabled(true);
 }
 
-Engine::~Engine()
-{
-    delete d;
-}
+Engine::~Engine() = default;
 
 QSharedPointer<GrantleeKi18nLocalizer> Engine::localizer() const
 {
